@@ -1,5 +1,6 @@
 """Main entrypoint for the CLI"""
 import sys
+import json
 
 from cognito_login.cognito_login import cognito_login
 from cognito_login.lib import exceptions
@@ -11,7 +12,7 @@ def main():
     try:
         result = cognito_login(*sys.argv[1:])
         if result:
-            print(result)
+            print(json.dumps(result.pop(), default=str))
     except exceptions.EarlyExit as early_exit:
         logger.debug('', exc_info=True)
         logger.debug(early_exit)
