@@ -1,8 +1,10 @@
 """Plugin hook driver for getting the jwt"""
+from typing import List, Dict
+
 from cognito_login.lib.plugins import plugin_manager
 
 
-def get_jwt(arguments: list) -> int:
+def get_jwt(arguments: list) -> List[Dict]:
     """Do the work"""
     plugin_manager.hook.pre_get_jwt( # pylint: disable=no-member
         arguments=arguments,
